function XRY = weakpref();
% XRY = weakpref();
% Calculates majority-rule weak preference for all pairs and
% returns it in matrix XRY. 
%
% The 2-dim index is converted to a single-number index (see 
% matlab functions SUB2IND and IND2SUB). Each entry in XRY
% is coded 1 if the row alternative is weakly preferred to the
% column alternative.
% 
% This requires the function F from the RB program and therefore
% uses the voter distribution currently stored in the matrix
% voterlocs.
% 
% Note: For strict preferences, simply change the weak equality
% to a strict equality in the last line of this code.
% [JW, 7/28/01]


global numpol numpol2

XRY=[];
UXY=[];

tol = 7;			% used for rounding

for i=1:numpol
   for j=1:numpol
      T=zeros(numpol);
      for m=1:numpol
         for n=1:numpol
            T(m,n)=f([i;j],[m;n]);
         end
      end
      UXY(sub2ind([numpol,numpol],i,j),:)=reshape(T,1,numpol2);
   end   
end

XRY = round((10^tol)*UXY)>=(10^tol)/2;