function DS = reach(XRY,x,n)
% DS = reach(XRY,x,n)
% REACH finds the set of alternatives from which it is possible
% to defeat policy x in n rounds of pairwise votes. XRY is a 
% pref relation matrix, e.g. using WEAKPREF; x is a 2-dim policy 
% vector, and n is an integer.
%
% For example, we want to consider policy [i,j]. REACH(XRY,[i,j],1)
% is equivalent to finding the winset of [i,j]. REACH(XRY,[i,j],2)
% is the union of the winsets of the elements of the winset of [i,j].
% 
% In the present model, it is useful for determining which policies
% might result after n rounds starting from x.
% [JW, 7/28/01]

DS = winset(XRY,x);
for i = 2:n
   for j=1:size(DS,1)
      DS = [DS;winset(XRY,DS(j,:))];
   end
   DS = unique(DS,'rows');
end
