function R = regime(H_Iparty, H_Isvotes, H_IP)

% R = regime(H_Iparty, H_Isvotes, H_IP)
% This function calculates a "regime" matrix: rows are unique entries
% for a continuous period of legislator service.
% This matrix R should help to calculate the following statistics
% calculate some more results, such as...
% length of service: min, max, avg, stdev
% re-election rate/challenger success rate
% policy change rate
% "data": H_Iparty, H_Isvotes, H_IP

R = [];
rnum = 1; % regime index
sor = 1; % start of regime
R(1,:) = [rnum, 0, H_IP(1,:), H_Isvotes(1), 0, 0, 0];

len = size(H_IP,1);

% unique regime number, number of terms, policy, first vote, 2nd vote, last vote, avg vote

for i = 2:len
    if H_Iparty(i) ~= H_Iparty(i-1)
        % calc and record for prev regime
        R(rnum, 2) = i - sor;
        if R(rnum,2) == 1
            R(rnum,6) = 0;
            R(rnum,7) = 0;
            R(rnum,8) = R(rnum,5);
        else
            R(rnum,6) = H_Isvotes(sor+1);
            R(rnum,7) = H_Isvotes(i-1);
            R(rnum,8) = mean(H_Isvotes(sor:i-1));
        end
        
        % stuff for new regime
            rnum = rnum + 1;
            R(rnum,:) = [rnum, 0, H_IP(i,:), 1-H_Isvotes(i), 0, 0, 0];
            sor = i;
    end
end  

% stuff for last term
if len == sor
    R(rnum,2) = 1;
    R(rnum,[6,7]) = [0,0];
    R(rnum,8) = R(rnum,5);
else
    R(rnum,2) = len-sor+1;
    R(rnum,6) = H_Isvotes(sor+1);
    R(rnum,7) = H_Isvotes(len);
    R(rnum,8) = mean(H_Isvotes(sor:len));
end