% This is a more general simulation framework, which allows both incumbent and challenger to
% have different search rules, and also incorporates party preferences.

disp('Running (general) simulations...')

mcec_init

% random starting values for now
if flag.startvals==0
   unif=ones(numpol)/numpol2;
   A = randomize(unif);
   B = randomize(unif);
   clear unif
end

% make sure incumbent policy is preferred to challenger policy in initial state
if f(A,B)>=.5
   IP=A;
   CP=B;
	Iparty = 0;   
else
   IP=B;
   CP=A;
   Iparty = 1;
end
Isvotes = f(IP,CP);
mcec_record;

for t=1:numit
   % convert transition probabilities into a propensity matrix for challenger,
   % then choose a policy accordingly
   if Iparty==0
      INEW = randomize(reshape(T_AI(sub2ind([numpol,numpol],IP(1),IP(2)),:),numpol,numpol));
      CNEW = randomize(reshape(T_BC(sub2ind([numpol,numpol],CP(1),CP(2)),:),numpol,numpol));
   elseif Iparty==1
      INEW = randomize(reshape(T_BI(sub2ind([numpol,numpol],IP(1),IP(2)),:),numpol,numpol));       
      CNEW = randomize(reshape(T_AC(sub2ind([numpol,numpol],CP(1),CP(2)),:),numpol,numpol));
   end
   
   
   % the election...
   Isvotes=f(INEW,CNEW);
   
   if Isvotes>.5
       % incumbent wins
      IP=INEW;
      CP=CNEW;
   elseif Isvotes<.5
       % challenger wins
      CP=INEW;
      IP=CNEW;
      Iparty = 1 - Iparty;
   elseif Isvotes==.5
      if rand>.5
         IP=INEW;
         CP=CNEW;
      else
         CP=INEW;
         IP=CNEW;
         Iparty = 1 - Iparty;
      end
   else
      disp('Error: Isvotes in mcec_main.m')
   end
   
   mcec_record;

end

D_IP=D_IP/sum(sum(D_IP));
D_CP=D_CP/sum(sum(D_CP));