function F = pick(X,s)
% F = pick(X,s)
% This function will pick out a row from X and reshape it into a square
% matrix; s needs to be a 2-dim vector. (X must also be a square matrix
% where the sqrt of the number of rows must be an integer.)
% 
% For example, each row of CTRANS or XRY refers to a specific alternative
% in 2-dim policy space. If we want to pick out the challenger transition
% probabilities when the challenger is located at [x,y], we would type
% pick(CTRANS,[x,y]). Similarly, if we want to see which alternatives are
% MR weakly preferred to [x,y], we would first use the function WEAKPREF, 
% then PICK as follows:
% 			XRY = weakpref
%			pick(XRY,[x,y])
%
% [JW, 7/28/01]

F = reshape(X(sub2ind(sqrt(size(X)),s(1),s(2)),:),sqrt(length(X)),sqrt(length(X)));